# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_comp.ipynb.

# %% auto 0
__all__ = ['islistordict']

# %% ../nbs/02_comp.ipynb 4
from typing import TypeGuard
from typing import Any, Union

# %% ../nbs/02_comp.ipynb 5
from .core import islist, isdict

# %% ../nbs/02_comp.ipynb 7
def islistordict(x: Any) -> TypeGuard[Union[list, dict]]:
    '''
    Check if `x` is a `list` or `dict`.

    Parameters
    ----------
    x : Any
        The variable to check.

    Returns
    -------
    TypeGuard[Union[list, dict]
        True if `x` is a `list` or `dict`, False otherwise.
    '''
    return islist(x) or isdict(x)
