# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/chck',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/chck',
                'lib_path': 'chck'},
  'syms': { 'chck.alls': { 'chck.alls.alldig': ('alls.html#alldig', 'chck/alls.py'),
                           'chck.alls.allint': ('alls.html#allint', 'chck/alls.py'),
                           'chck.alls.allmap': ('alls.html#allmap', 'chck/alls.py'),
                           'chck.alls.allsame': ('alls.html#allsame', 'chck/alls.py'),
                           'chck.alls.allstr': ('alls.html#allstr', 'chck/alls.py'),
                           'chck.alls.alltype': ('alls.html#alltype', 'chck/alls.py'),
                           'chck.alls.areinstances': ('alls.html#areinstances', 'chck/alls.py'),
                           'chck.alls.isints': ('alls.html#isints', 'chck/alls.py'),
                           'chck.alls.isstrs': ('alls.html#isstrs', 'chck/alls.py')},
            'chck.atyp': {},
            'chck.biol': { 'chck.biol.isadatafile': ('biol.html#isadatafile', 'chck/biol.py'),
                           'chck.biol.isadatapath': ('biol.html#isadatapath', 'chck/biol.py'),
                           'chck.biol.isbarcodesfile': ('biol.html#isbarcodesfile', 'chck/biol.py'),
                           'chck.biol.isbarcodespath': ('biol.html#isbarcodespath', 'chck/biol.py'),
                           'chck.biol.isfeaturesfile': ('biol.html#isfeaturesfile', 'chck/biol.py'),
                           'chck.biol.isfeaturespath': ('biol.html#isfeaturespath', 'chck/biol.py'),
                           'chck.biol.isfilteredmatrixdir': ('biol.html#isfilteredmatrixdir', 'chck/biol.py'),
                           'chck.biol.isfilteredmatrixpath': ('biol.html#isfilteredmatrixpath', 'chck/biol.py'),
                           'chck.biol.isfmat': ('biol.html#isfmat', 'chck/biol.py'),
                           'chck.biol.isfmatdir': ('biol.html#isfmatdir', 'chck/biol.py'),
                           'chck.biol.ismatrixfile': ('biol.html#ismatrixfile', 'chck/biol.py'),
                           'chck.biol.ismatrixpath': ('biol.html#ismatrixpath', 'chck/biol.py'),
                           'chck.biol.issens': ('biol.html#issens', 'chck/biol.py'),
                           'chck.biol.issensdir': ('biol.html#issensdir', 'chck/biol.py'),
                           'chck.biol.issensitivitydir': ('biol.html#issensitivitydir', 'chck/biol.py'),
                           'chck.biol.issensitivitypath': ('biol.html#issensitivitypath', 'chck/biol.py')},
            'chck.bool': { 'chck.bool.is01': ('bool.html#is01', 'chck/bool.py'),
                           'chck.bool.isbcall': ('bool.html#isbcall', 'chck/bool.py'),
                           'chck.bool.isboolcall': ('bool.html#isboolcall', 'chck/bool.py'),
                           'chck.bool.isbooltype': ('bool.html#isbooltype', 'chck/bool.py'),
                           'chck.bool.isbooly': ('bool.html#isbooly', 'chck/bool.py'),
                           'chck.bool.isbtype': ('bool.html#isbtype', 'chck/bool.py')},
            'chck.call': { 'chck.call.hasget': ('call.html#hasget', 'chck/call.py'),
                           'chck.call.haskeys': ('call.html#haskeys', 'chck/call.py'),
                           'chck.call.isattrcall': ('call.html#isattrcall', 'chck/call.py'),
                           'chck.call.iscallattr': ('call.html#iscallattr', 'chck/call.py')},
            'chck.comp': {'chck.comp.islistordict': ('comp.html#islistordict', 'chck/comp.py')},
            'chck.core': { 'chck.core.isany': ('core.html#isany', 'chck/core.py'),
                           'chck.core.isbool': ('core.html#isbool', 'chck/core.py'),
                           'chck.core.isbytes': ('core.html#isbytes', 'chck/core.py'),
                           'chck.core.iscall': ('core.html#iscall', 'chck/core.py'),
                           'chck.core.isclass': ('core.html#isclass', 'chck/core.py'),
                           'chck.core.iscls': ('core.html#iscls', 'chck/core.py'),
                           'chck.core.isdict': ('core.html#isdict', 'chck/core.py'),
                           'chck.core.isint': ('core.html#isint', 'chck/core.py'),
                           'chck.core.isiter': ('core.html#isiter', 'chck/core.py'),
                           'chck.core.islist': ('core.html#islist', 'chck/core.py'),
                           'chck.core.isnone': ('core.html#isnone', 'chck/core.py'),
                           'chck.core.isnum': ('core.html#isnum', 'chck/core.py'),
                           'chck.core.isrange': ('core.html#isrange', 'chck/core.py'),
                           'chck.core.isrng': ('core.html#isrng', 'chck/core.py'),
                           'chck.core.isset': ('core.html#isset', 'chck/core.py'),
                           'chck.core.isslc': ('core.html#isslc', 'chck/core.py'),
                           'chck.core.isslice': ('core.html#isslice', 'chck/core.py'),
                           'chck.core.isstr': ('core.html#isstr', 'chck/core.py'),
                           'chck.core.istup': ('core.html#istup', 'chck/core.py'),
                           'chck.core.istuple': ('core.html#istuple', 'chck/core.py'),
                           'chck.core.istype': ('core.html#istype', 'chck/core.py'),
                           'chck.core.notnone': ('core.html#notnone', 'chck/core.py')},
            'chck.dcls': {'chck.dcls.iskwotype': ('dcls.html#iskwotype', 'chck/dcls.py')},
            'chck.dict': { 'chck.dict.isdictitems': ('dict.html#isdictitems', 'chck/dict.py'),
                           'chck.dict.isdictiter': ('dict.html#isdictiter', 'chck/dict.py'),
                           'chck.dict.isdictkeys': ('dict.html#isdictkeys', 'chck/dict.py'),
                           'chck.dict.isdicttype': ('dict.html#isdicttype', 'chck/dict.py'),
                           'chck.dict.isdictvalues': ('dict.html#isdictvalues', 'chck/dict.py'),
                           'chck.dict.isditems': ('dict.html#isditems', 'chck/dict.py'),
                           'chck.dict.isditer': ('dict.html#isditer', 'chck/dict.py'),
                           'chck.dict.isdkeys': ('dict.html#isdkeys', 'chck/dict.py'),
                           'chck.dict.isdvals': ('dict.html#isdvals', 'chck/dict.py')},
            'chck.fref': { 'chck.fref.dereference': ('fref.html#dereference', 'chck/fref.py'),
                           'chck.fref.isforwardref': ('fref.html#isforwardref', 'chck/fref.py'),
                           'chck.fref.isfref': ('fref.html#isfref', 'chck/fref.py')},
            'chck.insp': { 'chck.insp.isclsarg': ('insp.html#isclsarg', 'chck/insp.py'),
                           'chck.insp.isempty': ('insp.html#isempty', 'chck/insp.py'),
                           'chck.insp.isfunc': ('insp.html#isfunc', 'chck/insp.py'),
                           'chck.insp.iskwonly': ('insp.html#iskwonly', 'chck/insp.py'),
                           'chck.insp.islambda': ('insp.html#islambda', 'chck/insp.py'),
                           'chck.insp.isp': ('insp.html#isp', 'chck/insp.py'),
                           'chck.insp.ispcls': ('insp.html#ispcls', 'chck/insp.py'),
                           'chck.insp.ispempty': ('insp.html#ispempty', 'chck/insp.py'),
                           'chck.insp.ispkwonly': ('insp.html#ispkwonly', 'chck/insp.py'),
                           'chck.insp.ispself': ('insp.html#ispself', 'chck/insp.py'),
                           'chck.insp.isself': ('insp.html#isself', 'chck/insp.py'),
                           'chck.insp.issig': ('insp.html#issig', 'chck/insp.py'),
                           'chck.insp.isspec': ('insp.html#isspec', 'chck/insp.py'),
                           'chck.insp.isvarkwd': ('insp.html#isvarkwd', 'chck/insp.py'),
                           'chck.insp.isvarpos': ('insp.html#isvarpos', 'chck/insp.py')},
            'chck.isad': { 'chck.isad.isad': ('isad.html#isad', 'chck/isad.py'),
                           'chck.isad.isanndata': ('isad.html#isanndata', 'chck/isad.py')},
            'chck.isan': { 'chck.isan.isad': ('isan.html#isad', 'chck/isan.py'),
                           'chck.isan.isanndata': ('isan.html#isanndata', 'chck/isan.py')},
            'chck.iscv': { 'chck.iscv.isvid': ('iscv.html#isvid', 'chck/iscv.py'),
                           'chck.iscv.isvideo': ('iscv.html#isvideo', 'chck/iscv.py'),
                           'chck.iscv.isvideocapture': ('iscv.html#isvideocapture', 'chck/iscv.py')},
            'chck.isnp': { 'chck.isnp.isarr': ('isnp.html#isarr', 'chck/isnp.py'),
                           'chck.isnp.ismtx': ('isnp.html#ismtx', 'chck/isnp.py'),
                           'chck.isnp.isnparr': ('isnp.html#isnparr', 'chck/isnp.py'),
                           'chck.isnp.isnparrary': ('isnp.html#isnparrary', 'chck/isnp.py'),
                           'chck.isnp.isnpmatrix': ('isnp.html#isnpmatrix', 'chck/isnp.py'),
                           'chck.isnp.isnpmtx': ('isnp.html#isnpmtx', 'chck/isnp.py'),
                           'chck.isnp.isnpnan': ('isnp.html#isnpnan', 'chck/isnp.py')},
            'chck.ispd': { 'chck.ispd.isbidx': ('ispd.html#isbidx', 'chck/ispd.py'),
                           'chck.ispd.isboolidx': ('ispd.html#isboolidx', 'chck/ispd.py'),
                           'chck.ispd.isboolindex': ('ispd.html#isboolindex', 'chck/ispd.py'),
                           'chck.ispd.iscategoricalindex': ('ispd.html#iscategoricalindex', 'chck/ispd.py'),
                           'chck.ispd.iscatidx': ('ispd.html#iscatidx', 'chck/ispd.py'),
                           'chck.ispd.iscidx': ('ispd.html#iscidx', 'chck/ispd.py'),
                           'chck.ispd.isdf': ('ispd.html#isdf', 'chck/ispd.py'),
                           'chck.ispd.isidx': ('ispd.html#isidx', 'chck/ispd.py'),
                           'chck.ispd.isidxlike': ('ispd.html#isidxlike', 'chck/ispd.py'),
                           'chck.ispd.isindexlike': ('ispd.html#isindexlike', 'chck/ispd.py'),
                           'chck.ispd.ispdna': ('ispd.html#ispdna', 'chck/ispd.py'),
                           'chck.ispd.isseries': ('ispd.html#isseries', 'chck/ispd.py'),
                           'chck.ispd.notpdna': ('ispd.html#notpdna', 'chck/ispd.py')},
            'chck.issp': { 'chck.issp.issparr': ('issp.html#issparr', 'chck/issp.py'),
                           'chck.issp.issparray': ('issp.html#issparray', 'chck/issp.py'),
                           'chck.issp.issparse': ('issp.html#issparse', 'chck/issp.py'),
                           'chck.issp.isspmatrix': ('issp.html#isspmatrix', 'chck/issp.py'),
                           'chck.issp.isspmtx': ('issp.html#isspmtx', 'chck/issp.py'),
                           'chck.issp.isspr': ('issp.html#isspr', 'chck/issp.py')},
            'chck.iter': { 'chck.iter.isiprod': ('iter.html#isiprod', 'chck/iter.py'),
                           'chck.iter.isiproduct': ('iter.html#isiproduct', 'chck/iter.py'),
                           'chck.iter.isiternotstr': ('iter.html#isiternotstr', 'chck/iter.py'),
                           'chck.iter.isiternotstrbytes': ('iter.html#isiternotstrbytes', 'chck/iter.py'),
                           'chck.iter.isiterprod': ('iter.html#isiterprod', 'chck/iter.py'),
                           'chck.iter.isiterproduct': ('iter.html#isiterproduct', 'chck/iter.py'),
                           'chck.iter.isproduct': ('iter.html#isproduct', 'chck/iter.py'),
                           'chck.iter.iternotstr': ('iter.html#iternotstr', 'chck/iter.py'),
                           'chck.iter.notiterstr': ('iter.html#notiterstr', 'chck/iter.py')},
            'chck.itrs': { 'chck.itrs.alldig': ('itrs.html#alldig', 'chck/itrs.py'),
                           'chck.itrs.allint': ('itrs.html#allint', 'chck/itrs.py'),
                           'chck.itrs.allmap': ('itrs.html#allmap', 'chck/itrs.py'),
                           'chck.itrs.alltype': ('itrs.html#alltype', 'chck/itrs.py')},
            'chck.lens': { 'chck.lens.has1': ('lens.html#has1', 'chck/lens.py'),
                           'chck.lens.has2': ('lens.html#has2', 'chck/lens.py'),
                           'chck.lens.has3': ('lens.html#has3', 'chck/lens.py'),
                           'chck.lens.has4': ('lens.html#has4', 'chck/lens.py'),
                           'chck.lens.hasn': ('lens.html#hasn', 'chck/lens.py'),
                           'chck.lens.is2ints': ('lens.html#is2ints', 'chck/lens.py'),
                           'chck.lens.is3ints': ('lens.html#is3ints', 'chck/lens.py'),
                           'chck.lens.is4ints': ('lens.html#is4ints', 'chck/lens.py'),
                           'chck.lens.ischar': ('lens.html#ischar', 'chck/lens.py'),
                           'chck.lens.ischr': ('lens.html#ischr', 'chck/lens.py'),
                           'chck.lens.islen1': ('lens.html#islen1', 'chck/lens.py'),
                           'chck.lens.islen2': ('lens.html#islen2', 'chck/lens.py'),
                           'chck.lens.islen3': ('lens.html#islen3', 'chck/lens.py'),
                           'chck.lens.islen4': ('lens.html#islen4', 'chck/lens.py'),
                           'chck.lens.islenn': ('lens.html#islenn', 'chck/lens.py'),
                           'chck.lens.isnints': ('lens.html#isnints', 'chck/lens.py')},
            'chck.misc': { 'chck.misc.arein': ('misc.html#arein', 'chck/misc.py'),
                           'chck.misc.isin': ('misc.html#isin', 'chck/misc.py'),
                           'chck.misc.isna': ('misc.html#isna', 'chck/misc.py'),
                           'chck.misc.notna': ('misc.html#notna', 'chck/misc.py')},
            'chck.path': { 'chck.path.isdir': ('path.html#isdir', 'chck/path.py'),
                           'chck.path.isfile': ('path.html#isfile', 'chck/path.py'),
                           'chck.path.ishidden': ('path.html#ishidden', 'chck/path.py'),
                           'chck.path.ispath': ('path.html#ispath', 'chck/path.py'),
                           'chck.path.ispathlike': ('path.html#ispathlike', 'chck/path.py'),
                           'chck.path.ispathy': ('path.html#ispathy', 'chck/path.py'),
                           'chck.path.isxath': ('path.html#isxath', 'chck/path.py')},
            'chck.pyty': { 'chck.pyty.isbuiltin': ('pyty.html#isbuiltin', 'chck/pyty.py'),
                           'chck.pyty.isbuiltinfunctiontype': ('pyty.html#isbuiltinfunctiontype', 'chck/pyty.py'),
                           'chck.pyty.ismethodwrapper': ('pyty.html#ismethodwrapper', 'chck/pyty.py'),
                           'chck.pyty.ismthdwrap': ('pyty.html#ismthdwrap', 'chck/pyty.py')},
            'chck.strs': { 'chck.strs.isallstr': ('strs.html#isallstr', 'chck/strs.py'),
                           'chck.strs.ischar': ('strs.html#ischar', 'chck/strs.py'),
                           'chck.strs.ischars': ('strs.html#ischars', 'chck/strs.py'),
                           'chck.strs.isdig': ('strs.html#isdig', 'chck/strs.py'),
                           'chck.strs.isdotstr': ('strs.html#isdotstr', 'chck/strs.py'),
                           'chck.strs.isdunder': ('strs.html#isdunder', 'chck/strs.py'),
                           'chck.strs.iselps': ('strs.html#iselps', 'chck/strs.py'),
                           'chck.strs.islower': ('strs.html#islower', 'chck/strs.py'),
                           'chck.strs.ismangled': ('strs.html#ismangled', 'chck/strs.py'),
                           'chck.strs.isnilstr': ('strs.html#isnilstr', 'chck/strs.py'),
                           'chck.strs.ispipe': ('strs.html#ispipe', 'chck/strs.py'),
                           'chck.strs.ispipestr': ('strs.html#ispipestr', 'chck/strs.py'),
                           'chck.strs.isprivate': ('strs.html#isprivate', 'chck/strs.py'),
                           'chck.strs.ispublic': ('strs.html#ispublic', 'chck/strs.py'),
                           'chck.strs.ispunc': ('strs.html#ispunc', 'chck/strs.py'),
                           'chck.strs.isquote': ('strs.html#isquote', 'chck/strs.py'),
                           'chck.strs.isstar': ('strs.html#isstar', 'chck/strs.py'),
                           'chck.strs.isstrbytes': ('strs.html#isstrbytes', 'chck/strs.py'),
                           'chck.strs.issunder': ('strs.html#issunder', 'chck/strs.py'),
                           'chck.strs.isuniqchrs': ('strs.html#isuniqchrs', 'chck/strs.py'),
                           'chck.strs.isupper': ('strs.html#isupper', 'chck/strs.py'),
                           'chck.strs.notstrbytes': ('strs.html#notstrbytes', 'chck/strs.py')},
            'chck.tgrd': { 'chck.tgrd.isinst': ('tgrd.html#isinst', 'chck/tgrd.py'),
                           'chck.tgrd.isinstq': ('tgrd.html#isinstq', 'chck/tgrd.py'),
                           'chck.tgrd.isof': ('tgrd.html#isof', 'chck/tgrd.py'),
                           'chck.tgrd.istypeq': ('tgrd.html#istypeq', 'chck/tgrd.py')},
            'chck.trch': { 'chck.trch.iscpu': ('trch.html#iscpu', 'chck/trch.py'),
                           'chck.trch.iscputensor': ('trch.html#iscputensor', 'chck/trch.py'),
                           'chck.trch.iscuda': ('trch.html#iscuda', 'chck/trch.py'),
                           'chck.trch.isdataframedataset': ('trch.html#isdataframedataset', 'chck/trch.py'),
                           'chck.trch.isdataloader': ('trch.html#isdataloader', 'chck/trch.py'),
                           'chck.trch.isdatamodule': ('trch.html#isdatamodule', 'chck/trch.py'),
                           'chck.trch.isdataset': ('trch.html#isdataset', 'chck/trch.py'),
                           'chck.trch.isdevice': ('trch.html#isdevice', 'chck/trch.py'),
                           'chck.trch.isdfdataset': ('trch.html#isdfdataset', 'chck/trch.py'),
                           'chck.trch.isdfds': ('trch.html#isdfds', 'chck/trch.py'),
                           'chck.trch.isdl': ('trch.html#isdl', 'chck/trch.py'),
                           'chck.trch.isdm': ('trch.html#isdm', 'chck/trch.py'),
                           'chck.trch.isds': ('trch.html#isds', 'chck/trch.py'),
                           'chck.trch.isdtype': ('trch.html#isdtype', 'chck/trch.py'),
                           'chck.trch.ismps': ('trch.html#ismps', 'chck/trch.py'),
                           'chck.trch.ismpstensor': ('trch.html#ismpstensor', 'chck/trch.py'),
                           'chck.trch.istens': ('trch.html#istens', 'chck/trch.py'),
                           'chck.trch.istensor': ('trch.html#istensor', 'chck/trch.py'),
                           'chck.trch.istorchtype': ('trch.html#istorchtype', 'chck/trch.py'),
                           'chck.trch.istrc': ('trch.html#istrc', 'chck/trch.py'),
                           'chck.trch.istrctype': ('trch.html#istrctype', 'chck/trch.py'),
                           'chck.trch.isttype': ('trch.html#isttype', 'chck/trch.py')},
            'chck.wrap': { 'chck.wrap.decoguard': ('wrap.html#decoguard', 'chck/wrap.py'),
                           'chck.wrap.guardanns': ('wrap.html#guardanns', 'chck/wrap.py'),
                           'chck.wrap.guarddocs': ('wrap.html#guarddocs', 'chck/wrap.py'),
                           'chck.wrap.guardname': ('wrap.html#guardname', 'chck/wrap.py'),
                           'chck.wrap.makeguard': ('wrap.html#makeguard', 'chck/wrap.py'),
                           'chck.wrap.setwrapattrs': ('wrap.html#setwrapattrs', 'chck/wrap.py'),
                           'chck.wrap.wrapguard': ('wrap.html#wrapguard', 'chck/wrap.py')}}}
