# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_dcls.ipynb.

# %% auto 0
__all__ = ['iskwotype']

# %% ../nbs/31_dcls.ipynb 4
from typing import TypeGuard
from dataclasses import _KW_ONLY_TYPE

# %% ../nbs/31_dcls.ipynb 6
def iskwotype(x) -> TypeGuard[_KW_ONLY_TYPE]:
    '''Check if `x` is of type `dataclasses.KW_ONLY`.'''
    return isinstance(x, _KW_ONLY_TYPE)
