# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/64_iscv.ipynb.

# %% auto 0
__all__ = ['isvideocapture', 'isvid', 'isvideo']

# %% ../nbs/64_iscv.ipynb 4
from typing import TypeGuard

# %% ../nbs/64_iscv.ipynb 5
from .atyp import VideoCapture, cvvideo

# %% ../nbs/64_iscv.ipynb 7
def isvideocapture(x) -> TypeGuard[cvvideo]:
    '''Check if `x` is a `cv2.VideoCapture`
    
     See Also
    --------
    isvid : Alias for `isvideocapture`
    isvideo : Alias for `isvideocapture`
    '''
    return isinstance(x, VideoCapture)

def isvid(x) -> TypeGuard[cvvideo]:
    '''Check if `x` is a `cv2.VideoCapture`
    
     See Also
    --------
    isvideo : Alias for `isvid`
    isvideocapture : Alias for `isvid`
    '''
    return isvideocapture(x)

def isvideo(x) -> TypeGuard[cvvideo]:
    '''Check if `x` is a `cv2.VideoCapture`
    
     See Also
    --------
    isvid : Alias for `isvideo`
    isvideocapture : Alias for `isvideo`
    '''
    return isvideocapture(x)
